#!/usr/bin/env bash

set -ex

AWS_ES=${AWS_ES:-false}
ES_PROTOCOL=${ES_PROTOCOL:-http}
ES_HOST=${ES_HOST:-elasticsearch}
ES_PORT=${ES_PORT:-9200}
ES_URL=${ES_URL:-"${ES_PROTOCOL}://${ES_HOST}:${ES_PORT}"}
ES_USER=${ES_USER}

CORRECT_FIELDS=${CORRECT_FIELDS:-""}

SOURCE_DIR=/job/src
OUTPUT_DIR=/tmp/output
ES_CONFIGURATION_FILE=${ES_CONFIGURATION_FILE:-default_configuration.yml}

AWS_OPTS=""
if [[ "${AWS_ES}" == "true" ]]; then
  AWS_REGION=${AWS_REGION:-us-west-2}
  AWS_OPTS="--aws --aws-region ${AWS_REGION}"
fi

if [[ "${CORRECT_FIELDS}" == "true" ]]; then
  CORRECT_FIELDS="--correct-fields"
fi

mkdir -p ${OUTPUT_DIR}

python ${SOURCE_DIR}/build_es_schema.py \
  --mappings-dir ${SOURCE_DIR}/resources/mappings \
  --settings-dir ${SOURCE_DIR}/resources/settings \
  --es-settings ${SOURCE_DIR}/${ES_CONFIGURATION_FILE} \
  --dao-config ${SOURCE_DIR}/resources/elasticsearch-dao.xml \
  --output-dir ${OUTPUT_DIR}

python /job/wait_for_es.py \
  --es-url ${ES_URL} \
  --es-user ${ES_USER} \
  ${AWS_OPTS}

python ${SOURCE_DIR}/upgrade_elasticsearch_schema.py \
  -v -v \
  --mappings \
  --mappings-dir ${OUTPUT_DIR}/mappings \
  --settings-dir ${OUTPUT_DIR}/settings \
  --config ${OUTPUT_DIR}/default_configuration.yml \
  --es-url-override ${ES_URL} \
  --es-event-url-override ${ES_URL} \
  --es-user ${ES_USER} \
  --add-missing-fields \
  --add-missing-indices \
  ${CORRECT_FIELDS} \
  --no-confirm \
  ${AWS_OPTS}

